SignalMeta

Struct SignalMeta 

pub struct SignalMeta {
    pub enum_map: HashMap<i128, String>,
    pub float_format: Option<FloatFormat>,
    pub sig_comment: Option<String>,
}
Signal metadata for a signal’s value interpretation and DBC description/comment.

Encapsulates optional formatting information for a signal, including enum mappings (for value descriptions) and float format specifications (for IEEE-754 encoded signals).

Also includes the signal-level description/comment from the DBC, if available.

Fields

enum_map: HashMap<i128, String>

Maps raw signal values to string enum labels from DBC value descriptions.

float_format: Option<FloatFormat>

The IEEE-754 float format, if this signal is an IEEE float/double.

sig_comment: Option<String>

Signal-level description/comment from the DBC.